reg.brief <-
function(my.formula, brief=TRUE, ...)

  Regression(my.formula, brief=TRUE, ...)

